.. _readme:

============================================================
OceanSpy - A Python Package for Oceanographic Investigations
============================================================

.. list-table::
    :stub-columns: 1
    :widths: 10 90

    * - docs
      - |docs|
    * - tests
      - |travis| |codecov|
    * - package
      - |version| |supported-versions| |license|

.. |docs| image:: http://readthedocs.org/projects/oceanspy/badge/?version=latest
    :alt: Documentation Status
    :target: http://oceanspy.readthedocs.io/en/latest/?badge=latest

.. |travis| image:: https://travis-ci.org/malmans2/oceanspy.svg?branch=master
    :alt: Travis
    :target: https://travis-ci.org/malmans2/oceanspy
    
.. |codecov| image:: https://codecov.io/github/malmans2/oceanspy/coverage.svg?branch=master
    :alt: Coverage
    :target: https://codecov.io/github/malmans2/oceanspy?branch=master

.. |version| image:: https://img.shields.io/pypi/v/oceanspy.svg?style=flat
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/oceanspy

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/oceanspy.svg?style=flat
    :alt: Supported versions
    :target: https://pypi.python.org/pypi/oceanspy
    
.. |license| image:: https://img.shields.io/github/license/mashape/apistatus.svg
   :alt: License
   :target: https://github.com/malmans2/oceanspy


**OceanSpy** is an open-source and user-friendly Python package that aims to enable scientists and interested amateurs to use oceanographic datasets as virtual sandboxes.
OceanSpy builds on software packages developed by the Pangeo_ community, and exploits the Johns Hopkins University SciServer_ system.

Our goal is to create a collaborative research environment where users can access and process high-resolution datasets.
For example, OceanSpy and SciServer allow to quickly analyze important aspects of model events in conjunction with observational data.

OceanSpy is currently suited to facilitate extracting information from Ocean General Circulation Models set up and run by the research group of `Prof. Tom Haine`_.
Users can either download subsets of data on their own machines, or run OceanSpy online storing post-processing files on SciServer.


.. _Prof. Tom Haine: http://sites.krieger.jhu.edu/haine
.. _Pangeo: http://pangeo-data.github.io
.. _SciServer: http://www.sciserver.org

